# :rabbit: pygitscrum

With pygitscrum you can masterize few git actions.!

# 💫 Demo

![demo_git](https://user-images.githubusercontent.com/45128847/137622385-fc899954-223c-4e14-9b4e-9f60492eb293.gif)
# 🚀 How use **pygitscrum**

Just run ``pygitscrum`` to see all available commands !

# ⚙️ Install

See [this page](INSTALL.md)

# :construction_worker: Contribution

See [this page](CONTRIBUTING.md)

# License

MIT License

Copyright (c) 2021 [thib1984](https://github.com/thib1984)

See [this page](LICENSE.txt) for details

